@@ -14,11 +14,10 @@ function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) r
  * This source code is licensed under the Apache-2.0 license found in the
  * LICENSE file in the root directory of this source tree.
  */
-import { settings } from 'carbon-components';
 import cx from 'classnames';
+import { usePrefix } from '../../internal/usePrefix';
 import PropTypes from 'prop-types';
 import React from 'react';
-var prefix = settings.prefix;
 
 function Accordion(_ref) {
   var _cx;
@@ -30,6 +29,7 @@ function Accordion(_ref) {
       size = _ref.size,
       rest = _objectWithoutProperties(_ref, _excluded);
 
+  var prefix = usePrefix();
   var className = cx("".concat(prefix, "--accordion"), customClassName, (_cx = {}, _defineProperty(_cx, "".concat(prefix, "--accordion--").concat(align), align), _defineProperty(_cx, "".concat(prefix, "--accordion--").concat(size), size), _cx));
   return /*#__PURE__*/React.createElement("ul", _extends({
     className: className
