@@ -46,12 +46,11 @@ import PropTypes from 'prop-types';
 import Button from '../Button';
 import ButtonSet from '../ButtonSet';
 import classNames from 'classnames';
-import { settings } from 'carbon-components';
 import { Close20 } from '@carbon/icons-react';
 import toggleClass from '../../tools/toggleClass';
 import requiredIfGivenPropIsTruthy from '../../prop-types/requiredIfGivenPropIsTruthy';
 import wrapFocus from '../../internal/wrapFocus';
-var prefix = settings.prefix;
+import { usePrefix, PrefixContext } from '../../internal/usePrefix';
 
 var ComposedModal = /*#__PURE__*/function (_Component) {
   _inherits(ComposedModal, _Component);
@@ -168,18 +167,18 @@ var ComposedModal = /*#__PURE__*/function (_Component) {
       }
 
       if (prevState.open !== this.state.open) {
-        toggleClass(document.body, "".concat(prefix, "--body--with-modal-open"), this.state.open);
+        toggleClass(document.body, "".concat(this.context, "--body--with-modal-open"), this.state.open);
       }
     }
   }, {
     key: "componentWillUnmount",
     value: function componentWillUnmount() {
-      toggleClass(document.body, "".concat(prefix, "--body--with-modal-open"), false);
+      toggleClass(document.body, "".concat(this.context, "--body--with-modal-open"), false);
     }
   }, {
     key: "componentDidMount",
     value: function componentDidMount() {
-      toggleClass(document.body, "".concat(prefix, "--body--with-modal-open"), this.props.open);
+      toggleClass(document.body, "".concat(this.context, "--body--with-modal-open"), this.props.open);
 
       if (!this.props.open) {
         return;
@@ -197,6 +196,7 @@ var ComposedModal = /*#__PURE__*/function (_Component) {
           _this2 = this;
 
       var open = this.state.open;
+      var prefix = this.context;
 
       var _this$props2 = this.props,
           ariaLabelledBy = _this$props2['aria-labelledby'],
@@ -274,6 +274,8 @@ var ComposedModal = /*#__PURE__*/function (_Component) {
   return ComposedModal;
 }(Component);
 
+_defineProperty(ComposedModal, "contextType", PrefixContext);
+
 _defineProperty(ComposedModal, "defaultProps", {
   onKeyDown: function onKeyDown() {},
   selectorPrimaryFocus: '[data-modal-primary-focus]'
@@ -327,6 +329,7 @@ export var ModalHeader = /*#__PURE__*/function (_Component2) {
           preventCloseOnClickOutside = _this$props3.preventCloseOnClickOutside,
           other = _objectWithoutProperties(_this$props3, _excluded2);
 
+      var prefix = this.context;
       var headerClass = classNames((_classNames3 = {}, _defineProperty(_classNames3, "".concat(prefix, "--modal-header"), true), _defineProperty(_classNames3, className, className), _classNames3));
       var labelClass = classNames((_classNames4 = {}, _defineProperty(_classNames4, "".concat(prefix, "--modal-header__label ").concat(prefix, "--type-delta"), true), _defineProperty(_classNames4, labelClassName, labelClassName), _classNames4));
       var titleClass = classNames((_classNames5 = {}, _defineProperty(_classNames5, "".concat(prefix, "--modal-header__heading ").concat(prefix, "--type-beta"), true), _defineProperty(_classNames5, titleClassName, titleClassName), _classNames5));
@@ -412,6 +415,8 @@ _defineProperty(ModalHeader, "propTypes", {
   titleClassName: PropTypes.string
 });
 
+_defineProperty(ModalHeader, "contextType", PrefixContext);
+
 _defineProperty(ModalHeader, "defaultProps", {
   iconDescription: 'Close',
   buttonOnClick: function buttonOnClick() {}
@@ -427,6 +432,7 @@ export function ModalBody(props) {
       preventCloseOnClickOutside = props.preventCloseOnClickOutside,
       other = _objectWithoutProperties(props, _excluded3);
 
+  var prefix = usePrefix();
   var contentClass = classNames((_classNames8 = {}, _defineProperty(_classNames8, "".concat(prefix, "--modal-content"), true), _defineProperty(_classNames8, "".concat(prefix, "--modal-content--with-form"), hasForm), _defineProperty(_classNames8, "".concat(prefix, "--modal-scroll-content"), hasScrollingContent), _defineProperty(_classNames8, className, className), _classNames8));
   var hasScrollingContentProps = hasScrollingContent ? {
     tabIndex: 0,
@@ -486,6 +492,7 @@ export var ModalFooter = /*#__PURE__*/function (_Component3) {
           inputref = _this$props4.inputref,
           other = _objectWithoutProperties(_this$props4, _excluded4);
 
+      var prefix = this.context;
       var footerClass = classNames((_classNames9 = {}, _defineProperty(_classNames9, "".concat(prefix, "--modal-footer"), true), _defineProperty(_classNames9, className, className), _defineProperty(_classNames9, "".concat(prefix, "--modal-footer--three-button"), Array.isArray(secondaryButtons) && secondaryButtons.length === 2), _classNames9));
       var primaryClass = classNames(_defineProperty({}, primaryClassName, primaryClassName));
       var secondaryClass = classNames(_defineProperty({}, secondaryClassName, secondaryClassName));
@@ -625,4 +632,6 @@ _defineProperty(ModalFooter, "propTypes", {
 _defineProperty(ModalFooter, "defaultProps", {
   onRequestClose: function onRequestClose() {},
   onRequestSubmit: function onRequestSubmit() {}
-});
\ No newline at end of file
+});
+
+_defineProperty(ModalFooter, "contextType", PrefixContext);
\ No newline at end of file
