@@ -250,7 +250,7 @@ var DataTable = /*#__PURE__*/function (_React$Component) {
       var totalSelected = _this.getSelectedRows().length;
 
       return _objectSpread(_objectSpread({}, props), {}, {
-        shouldShowBatchActions: shouldShowBatchActions,
+        shouldShowBatchActions: shouldShowBatchActions && totalSelected > 0,
         totalSelected: totalSelected,
         onCancel: _this.handleOnCancel
       });
@@ -277,9 +277,12 @@ var DataTable = /*#__PURE__*/function (_React$Component) {
     });
 
     _defineProperty(_assertThisInitialized(_this), "getTableContainerProps", function () {
-      var stickyHeader = _this.props.stickyHeader;
+      var _this$props2 = _this.props,
+          stickyHeader = _this$props2.stickyHeader,
+          useStaticWidth = _this$props2.useStaticWidth;
       return {
-        stickyHeader: stickyHeader
+        stickyHeader: stickyHeader,
+        useStaticWidth: useStaticWidth
       };
     });
 
@@ -509,11 +512,11 @@ var DataTable = /*#__PURE__*/function (_React$Component) {
       var _this3 = this;
 
       // eslint-disable-next-line react/prop-types
-      var _this$props2 = this.props,
-          children = _this$props2.children,
-          filterRows = _this$props2.filterRows,
-          headers = _this$props2.headers,
-          render = _this$props2.render;
+      var _this$props3 = this.props,
+          children = _this$props3.children,
+          filterRows = _this$props3.filterRows,
+          headers = _this$props3.headers,
+          render = _this$props3.render;
       var _this$state3 = this.state,
           filterInputValue = _this$state3.filterInputValue,
           rowIds = _this$state3.rowIds,
