@@ -1,3 +1,5 @@
+var _excluded = ["headers", "rowCount", "columnCount", "zebra", "compact", "className", "showHeader", "showToolbar"];
+
 function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
 
 function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
@@ -29,7 +31,7 @@ var DataTableSkeleton = function DataTableSkeleton(_ref) {
       className = _ref.className,
       showHeader = _ref.showHeader,
       showToolbar = _ref.showToolbar,
-      rest = _objectWithoutProperties(_ref, ["headers", "rowCount", "columnCount", "zebra", "compact", "className", "showHeader", "showToolbar"]);
+      rest = _objectWithoutProperties(_ref, _excluded);
 
   var dataTableSkeletonClasses = cx(className, (_cx = {}, _defineProperty(_cx, "".concat(prefix, "--skeleton"), true), _defineProperty(_cx, "".concat(prefix, "--data-table"), true), _defineProperty(_cx, "".concat(prefix, "--data-table--zebra"), zebra), _defineProperty(_cx, "".concat(prefix, "--data-table--compact"), compact), _cx));
   var rowRepeat = rowCount;
