@@ -1,17 +1,20 @@
-var _excluded = ["allowInput", "appendTo", "children", "className", "short", "light", "datePickerType", "minDate", "maxDate", "dateFormat", "onChange", "locale", "value"];
+var _excluded = ["allowInput", "appendTo", "datePickerType", "dateFormat", "locale", "minDate", "maxDate", "value", "onClose", "disable", "enable"],
+    _excluded2 = ["dateFormat", "minDate", "maxDate", "value", "disable", "enable"],
+    _excluded3 = ["dateFormat", "minDate", "maxDate", "value", "disable", "enable"],
+    _excluded4 = ["allowInput", "appendTo", "children", "className", "short", "light", "datePickerType", "minDate", "maxDate", "dateFormat", "onChange", "locale", "value"];
 
 function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
 
-function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
-
-function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
-
 function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }
 
 function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
 
 function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }
 
+function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
+
+function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
+
 function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
 
 function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }
@@ -57,13 +60,13 @@ import React, { Component } from 'react';
 import classNames from 'classnames';
 import flatpickr from 'flatpickr';
 import l10n from 'flatpickr/dist/l10n/index';
-import { settings } from 'carbon-components';
 import DatePickerInput from '../DatePickerInput';
 import carbonFlatpickrAppendToPlugin from './plugins/appendToPlugin';
 import carbonFlatpickrFixEventsPlugin from './plugins/fixEventsPlugin';
 import carbonFlatpickrRangePlugin from './plugins/rangePlugin';
 import { match, keys } from '../../internal/keyboard';
-var prefix = settings.prefix; // Weekdays shorthand for english locale
+import { FeatureFlagContext } from '../FeatureFlags';
+import { PrefixContext } from '../../internal/usePrefix'; // Weekdays shorthand for english locale
 
 l10n.en.weekdays.shorthand.forEach(function (day, index) {
   var currentDay = l10n.en.weekdays.shorthand;
@@ -214,17 +217,17 @@ var DatePicker = /*#__PURE__*/function (_Component) {
 
       if (calendarContainer && daysContainer) {
         // calendarContainer and daysContainer are undefined if flatpickr detects a mobile device
-        calendarContainer.classList.add("".concat(prefix, "--date-picker__calendar"));
-        calendarContainer.querySelector('.flatpickr-month').classList.add("".concat(prefix, "--date-picker__month"));
-        calendarContainer.querySelector('.flatpickr-weekdays').classList.add("".concat(prefix, "--date-picker__weekdays"));
-        calendarContainer.querySelector('.flatpickr-days').classList.add("".concat(prefix, "--date-picker__days"));
+        calendarContainer.classList.add("".concat(_this.context, "--date-picker__calendar"));
+        calendarContainer.querySelector('.flatpickr-month').classList.add("".concat(_this.context, "--date-picker__month"));
+        calendarContainer.querySelector('.flatpickr-weekdays').classList.add("".concat(_this.context, "--date-picker__weekdays"));
+        calendarContainer.querySelector('.flatpickr-days').classList.add("".concat(_this.context, "--date-picker__days"));
         forEach.call(calendarContainer.querySelectorAll('.flatpickr-weekday'), function (item) {
           var currentItem = item;
           currentItem.innerHTML = currentItem.innerHTML.replace(/\s+/g, '');
-          currentItem.classList.add("".concat(prefix, "--date-picker__weekday"));
+          currentItem.classList.add("".concat(_this.context, "--date-picker__weekday"));
         });
         forEach.call(daysContainer.querySelectorAll('.flatpickr-day'), function (item) {
-          item.classList.add("".concat(prefix, "--date-picker__day"));
+          item.classList.add("".concat(_this.context, "--date-picker__day"));
 
           if (item.classList.contains('today') && calendar.selectedDates.length > 0) {
             item.classList.add('no-border');
@@ -237,13 +240,13 @@ var DatePicker = /*#__PURE__*/function (_Component) {
 
     _defineProperty(_assertThisInitialized(_this), "assignInputFieldRef", function (node) {
       _this.inputField = !node ? null : // Child is a regular DOM node, seen in tests
-      node.nodeType === Node.ELEMENT_NODE ? node.querySelector(".".concat(prefix, "--date-picker__input")) : // Child is a React component
+      node.nodeType === Node.ELEMENT_NODE ? node.querySelector(".".concat(_this.context, "--date-picker__input")) : // Child is a React component
       node.input && node.input.nodeType === Node.ELEMENT_NODE ? node.input : null;
     });
 
     _defineProperty(_assertThisInitialized(_this), "assignToInputFieldRef", function (node) {
       _this.toInputField = !node ? null : // Child is a regular DOM node, seen in tests
-      node.nodeType === Node.ELEMENT_NODE ? node.querySelector(".".concat(prefix, "--date-picker__input")) : // Child is a React component
+      node.nodeType === Node.ELEMENT_NODE ? node.querySelector(".".concat(_this.context, "--date-picker__input")) : // Child is a React component
       node.input && node.input.nodeType === Node.ELEMENT_NODE ? node.input : null;
     });
 
@@ -272,7 +275,8 @@ var DatePicker = /*#__PURE__*/function (_Component) {
           value = _this$props.value,
           onClose = _this$props.onClose,
           disable = _this$props.disable,
-          enable = _this$props.enable;
+          enable = _this$props.enable,
+          rest = _objectWithoutProperties(_this$props, _excluded);
 
       if (datePickerType === 'single' || datePickerType === 'range') {
         var onHook = function onHook(electedDates, dateStr, instance) {
@@ -303,9 +307,10 @@ var DatePicker = /*#__PURE__*/function (_Component) {
 
 
         if (this.inputField) {
-          var _flatpickr;
+          var _rest$inline, _flatpickr;
 
           this.cal = new flatpickr(this.inputField, (_flatpickr = {
+            inline: (_rest$inline = rest.inline) !== null && _rest$inline !== void 0 ? _rest$inline : false,
             disableMobile: true,
             defaultDate: value,
             mode: datePickerType,
@@ -351,14 +356,17 @@ var DatePicker = /*#__PURE__*/function (_Component) {
           prevMaxDate = _ref.maxDate,
           prevValue = _ref.value,
           prevDisable = _ref.disable,
-          prevEnable = _ref.enable;
+          prevEnable = _ref.enable,
+          prevRest = _objectWithoutProperties(_ref, _excluded2);
+
       var _this$props2 = this.props,
           dateFormat = _this$props2.dateFormat,
           minDate = _this$props2.minDate,
           maxDate = _this$props2.maxDate,
           value = _this$props2.value,
           disable = _this$props2.disable,
-          enable = _this$props2.enable;
+          enable = _this$props2.enable,
+          rest = _objectWithoutProperties(_this$props2, _excluded3);
 
       if (this.cal) {
         if (prevDateFormat !== dateFormat) {
@@ -382,6 +390,10 @@ var DatePicker = /*#__PURE__*/function (_Component) {
         if (enable !== prevEnable) {
           this.cal.set('enable', enable);
         }
+
+        if (rest.inline && rest.inline !== (prevRest === null || prevRest === void 0 ? void 0 : prevRest.inline)) {
+          this.cal.set('inline', rest.inline);
+        }
       } // Coordinate when the given `value` prop changes. When this happens, we
       // should update the calendar to the new value.
 
@@ -423,61 +435,71 @@ var DatePicker = /*#__PURE__*/function (_Component) {
   }, {
     key: "render",
     value: function render() {
-      var _classNames,
-          _this3 = this;
+      var _this3 = this;
 
-      var _this$props3 = this.props,
-          allowInput = _this$props3.allowInput,
-          appendTo = _this$props3.appendTo,
-          children = _this$props3.children,
-          className = _this$props3.className,
-          short = _this$props3.short,
-          light = _this$props3.light,
-          datePickerType = _this$props3.datePickerType,
-          minDate = _this$props3.minDate,
-          maxDate = _this$props3.maxDate,
-          dateFormat = _this$props3.dateFormat,
-          onChange = _this$props3.onChange,
-          locale = _this$props3.locale,
-          value = _this$props3.value,
-          other = _objectWithoutProperties(_this$props3, _excluded);
+      return /*#__PURE__*/React.createElement(FeatureFlagContext.Consumer, null, function (scope) {
+        var _classNames;
 
-      var datePickerClasses = classNames("".concat(prefix, "--date-picker"), className, (_classNames = {}, _defineProperty(_classNames, "".concat(prefix, "--date-picker--short"), short), _defineProperty(_classNames, "".concat(prefix, "--date-picker--light"), light), _defineProperty(_classNames, "".concat(prefix, "--date-picker--simple"), datePickerType === 'simple'), _defineProperty(_classNames, "".concat(prefix, "--date-picker--single"), datePickerType === 'single'), _defineProperty(_classNames, "".concat(prefix, "--date-picker--range"), datePickerType === 'range'), _defineProperty(_classNames, "".concat(prefix, "--date-picker--nolabel"), datePickerType === 'range' && this.isLabelTextEmpty(children)), _classNames));
-      var childArray = React.Children.toArray(children);
-      var childrenWithProps = childArray.map(function (child, index) {
-        if (index === 0 && child.type === /*#__PURE__*/React.createElement(DatePickerInput, child.props).type) {
-          return /*#__PURE__*/React.cloneElement(child, {
-            datePickerType: datePickerType,
-            ref: _this3.assignInputFieldRef,
-            openCalendar: _this3.openCalendar
-          });
+        var _this3$props = _this3.props,
+            allowInput = _this3$props.allowInput,
+            appendTo = _this3$props.appendTo,
+            children = _this3$props.children,
+            className = _this3$props.className,
+            short = _this3$props.short,
+            light = _this3$props.light,
+            datePickerType = _this3$props.datePickerType,
+            minDate = _this3$props.minDate,
+            maxDate = _this3$props.maxDate,
+            dateFormat = _this3$props.dateFormat,
+            onChange = _this3$props.onChange,
+            locale = _this3$props.locale,
+            value = _this3$props.value,
+            other = _objectWithoutProperties(_this3$props, _excluded4);
+
+        var enabled;
+
+        if (scope.enabled) {
+          enabled = scope.enabled('enable-v11-release');
         }
 
-        if (index === 1 && child.type === /*#__PURE__*/React.createElement(DatePickerInput, child.props).type) {
-          return /*#__PURE__*/React.cloneElement(child, {
-            datePickerType: datePickerType,
-            ref: _this3.assignToInputFieldRef,
-            openCalendar: _this3.openCalendar
-          });
-        }
+        var datePickerClasses = classNames("".concat(_this3.context, "--date-picker"), [enabled ? null : className], (_classNames = {}, _defineProperty(_classNames, "".concat(_this3.context, "--date-picker--short"), short), _defineProperty(_classNames, "".concat(_this3.context, "--date-picker--light"), light), _defineProperty(_classNames, "".concat(_this3.context, "--date-picker--simple"), datePickerType === 'simple'), _defineProperty(_classNames, "".concat(_this3.context, "--date-picker--single"), datePickerType === 'single'), _defineProperty(_classNames, "".concat(_this3.context, "--date-picker--range"), datePickerType === 'range'), _defineProperty(_classNames, "".concat(_this3.context, "--date-picker--nolabel"), datePickerType === 'range' && _this3.isLabelTextEmpty(children)), _classNames));
+        var wrapperClasses = classNames("".concat(_this3.context, "--form-item"), [enabled ? className : null]);
+        var childArray = React.Children.toArray(children);
+        var childrenWithProps = childArray.map(function (child, index) {
+          if (index === 0 && child.type === /*#__PURE__*/React.createElement(DatePickerInput, child.props).type) {
+            return /*#__PURE__*/React.cloneElement(child, {
+              datePickerType: datePickerType,
+              ref: _this3.assignInputFieldRef,
+              openCalendar: _this3.openCalendar
+            });
+          }
 
-        if (index === 0) {
-          return /*#__PURE__*/React.cloneElement(child, {
-            ref: _this3.assignInputFieldRef
-          });
-        }
+          if (index === 1 && child.type === /*#__PURE__*/React.createElement(DatePickerInput, child.props).type) {
+            return /*#__PURE__*/React.cloneElement(child, {
+              datePickerType: datePickerType,
+              ref: _this3.assignToInputFieldRef,
+              openCalendar: _this3.openCalendar
+            });
+          }
 
-        if (index === 1) {
-          return /*#__PURE__*/React.cloneElement(child, {
-            ref: _this3.assignToInputFieldRef
-          });
-        }
+          if (index === 0) {
+            return /*#__PURE__*/React.cloneElement(child, {
+              ref: _this3.assignInputFieldRef
+            });
+          }
+
+          if (index === 1) {
+            return /*#__PURE__*/React.cloneElement(child, {
+              ref: _this3.assignToInputFieldRef
+            });
+          }
+        });
+        return /*#__PURE__*/React.createElement("div", {
+          className: wrapperClasses
+        }, /*#__PURE__*/React.createElement("div", _extends({
+          className: datePickerClasses
+        }, other), childrenWithProps));
       });
-      return /*#__PURE__*/React.createElement("div", {
-        className: "".concat(prefix, "--form-item")
-      }, /*#__PURE__*/React.createElement("div", _extends({
-        className: datePickerClasses
-      }, other), childrenWithProps));
     }
   }]);
 
@@ -645,4 +667,6 @@ _defineProperty(DatePicker, "defaultProps", {
   locale: 'en'
 });
 
+_defineProperty(DatePicker, "contextType", PrefixContext);
+
 export { DatePicker as default };
\ No newline at end of file
