@@ -15,15 +15,15 @@ function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) r
 import PropTypes from 'prop-types';
 import React from 'react';
 import cx from 'classnames';
-import { settings } from 'carbon-components';
 import SkeletonText from '../SkeletonText';
 import ButtonSkeleton from '../Button/Button.Skeleton';
-var prefix = settings.prefix;
+import { usePrefix } from '../../internal/usePrefix';
 
 function FileUploaderSkeleton(_ref) {
   var className = _ref.className,
       rest = _objectWithoutProperties(_ref, _excluded);
 
+  var prefix = usePrefix();
   return /*#__PURE__*/React.createElement("div", _extends({
     className: cx("".concat(prefix, "--form-item"), className)
   }, rest), /*#__PURE__*/React.createElement(SkeletonText, {
