@@ -26,14 +26,13 @@ function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) r
  * This source code is licensed under the Apache-2.0 license found in the
  * LICENSE file in the root directory of this source tree.
  */
-import { settings } from 'carbon-components';
 import cx from 'classnames';
 import PropTypes from 'prop-types';
 import React, { useRef, useState } from 'react';
 import { matches, keys } from '../../internal/keyboard';
 import { ButtonKinds } from '../../prop-types/types';
 import uid from '../../tools/uniqueId';
-var prefix = settings.prefix;
+import { usePrefix } from '../../internal/usePrefix';
 
 function noop() {}
 
@@ -63,6 +62,8 @@ function FileUploaderButton(_ref) {
       tabIndex = _ref$tabIndex === void 0 ? 0 : _ref$tabIndex,
       other = _objectWithoutProperties(_ref, _excluded);
 
+  var prefix = usePrefix();
+
   var _useState = useState(ownerLabelText),
       _useState2 = _slicedToArray(_useState, 2),
       labelText = _useState2[0],
@@ -111,12 +112,12 @@ function FileUploaderButton(_ref) {
 
   return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("label", _extends({
     tabIndex: disabled ? -1 : tabIndex || 0,
-    "aria-disabled": disabled,
     className: classes,
     onKeyDown: onKeyDown,
     htmlFor: inputId
   }, other), /*#__PURE__*/React.createElement("span", {
-    role: role
+    role: role,
+    "aria-disabled": disabled
   }, labelText)), /*#__PURE__*/React.createElement("input", {
     className: "".concat(prefix, "--visually-hidden"),
     ref: inputNode,
