@@ -15,8 +15,7 @@ function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) r
 import PropTypes from 'prop-types';
 import React from 'react';
 import classnames from 'classnames';
-import { settings } from 'carbon-components';
-var prefix = settings.prefix;
+import { usePrefix } from '../../internal/usePrefix';
 
 var FormLabel = function FormLabel(_ref) {
   var className = _ref.className,
@@ -24,6 +23,7 @@ var FormLabel = function FormLabel(_ref) {
       id = _ref.id,
       other = _objectWithoutProperties(_ref, _excluded);
 
+  var prefix = usePrefix();
   var classNames = classnames("".concat(prefix, "--label"), className);
   return /*#__PURE__*/React.createElement("label", _extends({
     htmlFor: id,
