@@ -25,7 +25,6 @@ function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
  * LICENSE file in the root directory of this source tree.
  */
 import { WarningFilled16, WarningAltFilled16 } from '@carbon/icons-react';
-import { settings } from 'carbon-components';
 import cx from 'classnames';
 import Downshift, { useSelect } from 'downshift';
 import isEqual from 'lodash.isequal';
@@ -40,7 +39,8 @@ import setupGetInstanceId from '../../tools/setupGetInstanceId';
 import { mapDownshiftProps } from '../../tools/createPropAdapter';
 import mergeRefs from '../../tools/mergeRefs';
 import { keys, match } from '../../internal/keyboard';
-var prefix = settings.prefix;
+import { useFeatureFlag } from '../FeatureFlags';
+import { usePrefix } from '../../internal/usePrefix';
 
 var noop = function noop() {};
 
@@ -60,6 +60,7 @@ var MultiSelect = /*#__PURE__*/React.forwardRef(function MultiSelect(_ref, ref)
   var containerClassName = _ref.className,
       id = _ref.id,
       items = _ref.items,
+      itemToElement = _ref.itemToElement,
       _itemToString = _ref.itemToString,
       titleText = _ref.titleText,
       helperText = _ref.helperText,
@@ -85,6 +86,7 @@ var MultiSelect = /*#__PURE__*/React.forwardRef(function MultiSelect(_ref, ref)
       onChange = _ref.onChange,
       onMenuChange = _ref.onMenuChange,
       direction = _ref.direction;
+  var prefix = usePrefix();
 
   var _useRef = useRef(getInstanceId()),
       multiSelectInstanceId = _useRef.current;
@@ -159,12 +161,15 @@ var MultiSelect = /*#__PURE__*/React.forwardRef(function MultiSelect(_ref, ref)
 
   var inline = type === 'inline';
   var showWarning = !invalid && warn;
-  var wrapperClasses = cx("".concat(prefix, "--multi-select__wrapper"), "".concat(prefix, "--list-box__wrapper"), (_cx = {}, _defineProperty(_cx, "".concat(prefix, "--multi-select__wrapper--inline"), inline), _defineProperty(_cx, "".concat(prefix, "--list-box__wrapper--inline"), inline), _defineProperty(_cx, "".concat(prefix, "--multi-select__wrapper--inline--invalid"), inline && invalid), _defineProperty(_cx, "".concat(prefix, "--list-box__wrapper--inline--invalid"), inline && invalid), _cx));
+  var enabled = useFeatureFlag('enable-v11-release');
+  var wrapperClasses = cx("".concat(prefix, "--multi-select__wrapper"), "".concat(prefix, "--list-box__wrapper"), [enabled ? containerClassName : null], (_cx = {}, _defineProperty(_cx, "".concat(prefix, "--multi-select__wrapper--inline"), inline), _defineProperty(_cx, "".concat(prefix, "--list-box__wrapper--inline"), inline), _defineProperty(_cx, "".concat(prefix, "--multi-select__wrapper--inline--invalid"), inline && invalid), _defineProperty(_cx, "".concat(prefix, "--list-box__wrapper--inline--invalid"), inline && invalid), _cx));
   var titleClasses = cx("".concat(prefix, "--label"), _defineProperty({}, "".concat(prefix, "--label--disabled"), disabled));
   var helperId = !helperText ? undefined : "multiselect-helper-text-".concat(multiSelectInstanceId);
   var fieldLabelId = "multiselect-field-label-".concat(multiSelectInstanceId);
   var helperClasses = cx("".concat(prefix, "--form__helper-text"), _defineProperty({}, "".concat(prefix, "--form__helper-text--disabled"), disabled));
-  var className = cx("".concat(prefix, "--multi-select"), containerClassName, (_cx4 = {}, _defineProperty(_cx4, "".concat(prefix, "--multi-select--invalid"), invalid), _defineProperty(_cx4, "".concat(prefix, "--multi-select--warning"), showWarning), _defineProperty(_cx4, "".concat(prefix, "--multi-select--inline"), inline), _defineProperty(_cx4, "".concat(prefix, "--multi-select--selected"), selectedItems && selectedItems.length > 0), _defineProperty(_cx4, "".concat(prefix, "--list-box--up"), direction === 'top'), _cx4));
+  var className = cx("".concat(prefix, "--multi-select"), [enabled ? null : containerClassName], (_cx4 = {}, _defineProperty(_cx4, "".concat(prefix, "--multi-select--invalid"), invalid), _defineProperty(_cx4, "".concat(prefix, "--multi-select--warning"), showWarning), _defineProperty(_cx4, "".concat(prefix, "--multi-select--inline"), inline), _defineProperty(_cx4, "".concat(prefix, "--multi-select--selected"), selectedItems && selectedItems.length > 0), _defineProperty(_cx4, "".concat(prefix, "--list-box--up"), direction === 'top'), _cx4)); // needs to be capitalized for react to render it correctly
+
+  var ItemToElement = itemToElement;
   var sortOptions = {
     selectedItems: controlledSelectedItems,
     itemToString: _itemToString,
@@ -284,7 +289,9 @@ var MultiSelect = /*#__PURE__*/React.forwardRef(function MultiSelect(_ref, ref)
       className: "".concat(prefix, "--checkbox-label"),
       "data-contained-checkbox-state": isChecked,
       id: "".concat(itemProps.id, "__checkbox")
-    }, itemText)));
+    }, itemToElement ? /*#__PURE__*/React.createElement(ItemToElement, _extends({
+      key: itemProps.id
+    }, item)) : itemText)));
   }))), !inline && !invalid && !warn && helperText && /*#__PURE__*/React.createElement("div", {
     id: helperId,
     className: helperClasses
@@ -338,6 +345,12 @@ MultiSelect.propTypes = _objectSpread(_objectSpread({}, sortingPropTypes), {}, {
    */
   invalidText: PropTypes.node,
 
+  /**
+   * Function to render items as custom components instead of strings.
+   * Defaults to null and is overridden by a getter
+   */
+  itemToElement: PropTypes.func,
+
   /**
    * Helper function passed to downshift that allows the library to render a
    * given item to a string label. By default, it extracts the `label` field
