@@ -36,13 +36,13 @@ function _defineProperty(obj, key, value) { if (key in obj) { Object.definePrope
  * This source code is licensed under the Apache-2.0 license found in the
  * LICENSE file in the root directory of this source tree.
  */
-import { settings } from 'carbon-components';
 import classNames from 'classnames';
 import PropTypes from 'prop-types';
 import React from 'react';
 import { warning } from '../../internal/warning';
 import uid from '../../tools/uniqueId';
-var prefix = settings.prefix;
+import { Text } from '../Text';
+import { PrefixContext } from '../../internal/usePrefix';
 
 var RadioButton = /*#__PURE__*/function (_React$Component) {
   _inherits(RadioButton, _React$Component);
@@ -60,6 +60,8 @@ var RadioButton = /*#__PURE__*/function (_React$Component) {
 
     _this = _super.call.apply(_super, [this].concat(args));
 
+    _defineProperty(_assertThisInitialized(_this), "prefix", _this.context);
+
     _defineProperty(_assertThisInitialized(_this), "uid", _this.props.id || uid());
 
     _defineProperty(_assertThisInitialized(_this), "handleChange", function (evt) {
@@ -72,6 +74,8 @@ var RadioButton = /*#__PURE__*/function (_React$Component) {
   _createClass(RadioButton, [{
     key: "render",
     value: function render() {
+      var prefix = this.prefix;
+
       var _this$props = this.props,
           className = _this$props.className,
           labelText = _this$props.labelText,
@@ -99,7 +103,7 @@ var RadioButton = /*#__PURE__*/function (_React$Component) {
         className: "".concat(prefix, "--radio-button__label")
       }, /*#__PURE__*/React.createElement("span", {
         className: "".concat(prefix, "--radio-button__appearance")
-      }), labelText && /*#__PURE__*/React.createElement("span", {
+      }), labelText && /*#__PURE__*/React.createElement(Text, {
         className: innerLabelClasses
       }, labelText)));
     }
@@ -173,6 +177,8 @@ _defineProperty(RadioButton, "propTypes", {
   value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired
 });
 
+_defineProperty(RadioButton, "contextType", PrefixContext);
+
 _defineProperty(RadioButton, "defaultProps", {
   labelText: '',
   labelPosition: 'right',
