@@ -14,6 +14,7 @@ import SelectItem from '../SelectItem';
 import SelectItemGroup from '../SelectItemGroup';
 import SelectSkeleton from '../Select/Select.Skeleton';
 import mdx from './Select.mdx';
+import { FeatureFlags } from '../FeatureFlags';
 var sizes = {
   'Small  (sm)': 'sm',
   'Medium (md) - default': undefined,
@@ -112,4 +113,65 @@ Skeleton.parameters = {
   info: {
     text: "\n        Placeholder skeleton state to use when content is loading.\n      "
   }
+};
+export var classNameChangeTest = function classNameChangeTest() {
+  return /*#__PURE__*/React.createElement("div", {
+    style: {
+      width: 400
+    }
+  }, /*#__PURE__*/React.createElement(Select, {
+    className: "TEST_CLASS",
+    id: "select-1",
+    defaultValue: "placeholder-item"
+  }, /*#__PURE__*/React.createElement(SelectItem, {
+    disabled: true,
+    hidden: true,
+    value: "placeholder-item",
+    text: "The class should be added to the label"
+  }), /*#__PURE__*/React.createElement(SelectItemGroup, {
+    label: "Category 1"
+  }, /*#__PURE__*/React.createElement(SelectItem, {
+    value: "option-1",
+    text: "Option 1"
+  }), /*#__PURE__*/React.createElement(SelectItem, {
+    value: "option-2",
+    text: "Option 2"
+  })), /*#__PURE__*/React.createElement(SelectItemGroup, {
+    label: "Category 2"
+  }, /*#__PURE__*/React.createElement(SelectItem, {
+    value: "option-3",
+    text: "Option 3"
+  }), /*#__PURE__*/React.createElement(SelectItem, {
+    value: "option-4",
+    text: "Option 4"
+  }))), /*#__PURE__*/React.createElement("br", null), /*#__PURE__*/React.createElement(FeatureFlags, {
+    flags: {
+      'enable-v11-release': true
+    }
+  }, /*#__PURE__*/React.createElement(Select, {
+    className: "TEST_CLASS",
+    id: "select-1",
+    defaultValue: "placeholder-item"
+  }, /*#__PURE__*/React.createElement(SelectItem, {
+    disabled: true,
+    hidden: true,
+    value: "placeholder-item",
+    text: "The class should be added to the wrapper"
+  }), /*#__PURE__*/React.createElement(SelectItemGroup, {
+    label: "Category 1"
+  }, /*#__PURE__*/React.createElement(SelectItem, {
+    value: "option-1",
+    text: "Option 1"
+  }), /*#__PURE__*/React.createElement(SelectItem, {
+    value: "option-2",
+    text: "Option 2"
+  })), /*#__PURE__*/React.createElement(SelectItemGroup, {
+    label: "Category 2"
+  }, /*#__PURE__*/React.createElement(SelectItem, {
+    value: "option-3",
+    text: "Option 3"
+  }), /*#__PURE__*/React.createElement(SelectItem, {
+    value: "option-4",
+    text: "Option 4"
+  })))));
 };
\ No newline at end of file
