@@ -17,8 +17,7 @@ function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) r
 import React from 'react';
 import PropTypes from 'prop-types';
 import classNames from 'classnames';
-import { settings } from 'carbon-components';
-var prefix = settings.prefix;
+import { usePrefix } from '../../internal/usePrefix';
 
 var SkeletonPlaceholder = function SkeletonPlaceholder(_ref) {
   var _classNames;
@@ -26,6 +25,7 @@ var SkeletonPlaceholder = function SkeletonPlaceholder(_ref) {
   var className = _ref.className,
       other = _objectWithoutProperties(_ref, _excluded);
 
+  var prefix = usePrefix();
   var skeletonPlaceholderClasses = classNames((_classNames = {}, _defineProperty(_classNames, "".concat(prefix, "--skeleton__placeholder"), true), _defineProperty(_classNames, className, className), _classNames));
   return /*#__PURE__*/React.createElement("div", _extends({
     className: skeletonPlaceholderClasses
