@@ -7,17 +7,16 @@ function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "functi
  * LICENSE file in the root directory of this source tree.
  */
 import React from 'react';
-import { settings } from 'carbon-components';
 import { shallow, mount } from 'enzyme';
 import Tabs from '../Tabs';
 import Tab from '../Tab';
 import TabsSkeleton from '../Tabs/Tabs.Skeleton';
-var prefix = settings.prefix;
+var prefix = 'bx';
 Element.prototype.scrollIntoView = jest.fn();
 describe('Tabs', function () {
   describe('renders as expected', function () {
     describe('navigation (<div>)', function () {
-      var wrapper = shallow( /*#__PURE__*/React.createElement(Tabs, {
+      var wrapper = mount( /*#__PURE__*/React.createElement(Tabs, {
         className: "extra-class"
       }, /*#__PURE__*/React.createElement(Tab, {
         label: "firstTab"
@@ -36,7 +35,7 @@ describe('Tabs', function () {
         expect(wrapper.find('div').first().hasClass("".concat(prefix, "--tabs--scrollable"))).toBe(true);
       });
       it('supports container variant', function () {
-        expect(shallow( /*#__PURE__*/React.createElement(Tabs, {
+        expect(mount( /*#__PURE__*/React.createElement(Tabs, {
           className: "extra-class",
           type: "container"
         }, /*#__PURE__*/React.createElement(Tab, {
