@@ -97,7 +97,7 @@ describe('Tag', function () {
       type: "red",
       renderIcon: Add16
     }, "This is a tag"));
-    expect(tag.childAt(0).hasClass('bx--tag__custom-icon'));
+    expect(tag.childAt(0).hasClass('bx--tag__custom-icon')).toBe(true);
   });
   it('should support extra class names', function () {
     var tag = shallow( /*#__PURE__*/React.createElement(Tag, {
