@@ -15,14 +15,14 @@ function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) r
 import PropTypes from 'prop-types';
 import React from 'react';
 import cx from 'classnames';
-import { settings } from 'carbon-components';
-var prefix = settings.prefix;
+import { usePrefix } from '../../internal/usePrefix';
 
 var TextAreaSkeleton = function TextAreaSkeleton(_ref) {
   var hideLabel = _ref.hideLabel,
       className = _ref.className,
       rest = _objectWithoutProperties(_ref, _excluded);
 
+  var prefix = usePrefix();
   return /*#__PURE__*/React.createElement("div", _extends({
     className: cx("".concat(prefix, "--form-item"), className)
   }, rest), !hideLabel && /*#__PURE__*/React.createElement("span", {
