@@ -40,6 +40,7 @@ import PropTypes from 'prop-types';
 import React, { Component } from 'react';
 import classNames from 'classnames';
 import { settings } from 'carbon-components';
+import { FeatureFlagContext } from '../FeatureFlags';
 var prefix = settings.prefix;
 
 var TimePicker = /*#__PURE__*/function (_Component) {
@@ -89,8 +90,15 @@ var TimePicker = /*#__PURE__*/function (_Component) {
           size = _this$props.size,
           other = _objectWithoutProperties(_this$props, _excluded);
 
+      var scope = this.context;
+      var enabled;
+
+      if (scope.enabled) {
+        enabled = scope.enabled('enable-v11-release');
+      }
+
       var timePickerInputProps = {
-        className: classNames("".concat(prefix, "--time-picker__input-field"), "".concat(prefix, "--text-input"), className, _defineProperty({}, "".concat(prefix, "--text-input--light"), light)),
+        className: classNames("".concat(prefix, "--time-picker__input-field"), "".concat(prefix, "--text-input"), [enabled ? null : className], _defineProperty({}, "".concat(prefix, "--text-input--light"), light)),
         onChange: function onChange(evt) {
           if (!other.disabled) {
             _this2.setState({
@@ -135,7 +143,7 @@ var TimePicker = /*#__PURE__*/function (_Component) {
         className: "".concat(prefix, "--form-requirement")
       }, invalidText) : null;
       return /*#__PURE__*/React.createElement("div", {
-        className: "".concat(prefix, "--form-item")
+        className: enabled ? classNames("".concat(prefix, "--form-item"), className) : "".concat(prefix, "--form-item")
       }, label, /*#__PURE__*/React.createElement("div", {
         className: timePickerClasses
       }, /*#__PURE__*/React.createElement("div", {
@@ -270,4 +278,6 @@ _defineProperty(TimePicker, "defaultProps", {
   light: false
 });
 
+_defineProperty(TimePicker, "contextType", FeatureFlagContext);
+
 export { TimePicker as default };
\ No newline at end of file
