@@ -1,3 +1,5 @@
+var _excluded = ["className"];
+
 function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }
 
 function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
@@ -25,7 +27,7 @@ var wrapComponent = function wrapComponent(_ref) {
 
   var Component = function Component(_ref2) {
     var baseClassName = _ref2.className,
-        other = _objectWithoutProperties(_ref2, ["className"]);
+        other = _objectWithoutProperties(_ref2, _excluded);
 
     var componentClass = cx(className, baseClassName);
     return /*#__PURE__*/React.createElement(type, _objectSpread(_objectSpread({}, other), {}, {
