@@ -1128,7 +1128,8 @@ module.exports = {
 		"11.4.9",
 		"11.4.10",
 		"11.4.11",
-		"11.4.12"
+		"11.4.12",
+		"11.5.0"
 	],
 	"89.0.4328.0": [
 		"12.0.0-beta.1",
@@ -1231,7 +1232,12 @@ module.exports = {
 		"12.0.14",
 		"12.0.15",
 		"12.0.16",
-		"12.0.17"
+		"12.0.17",
+		"12.0.18",
+		"12.1.0",
+		"12.1.1",
+		"12.1.2",
+		"12.2.0"
 	],
 	"90.0.4402.0": [
 		"13.0.0-beta.2",
@@ -1356,7 +1362,11 @@ module.exports = {
 		"13.1.9",
 		"13.2.0",
 		"13.2.1",
-		"13.2.2"
+		"13.2.2",
+		"13.2.3",
+		"13.3.0",
+		"13.4.0",
+		"13.5.0"
 	],
 	"92.0.4511.0": [
 		"14.0.0-beta.1",
@@ -1429,6 +1439,10 @@ module.exports = {
 		"14.0.0-beta.22",
 		"14.0.0-beta.23"
 	],
+	"93.0.4577.51": [
+		"14.0.0-beta.24",
+		"14.0.0-beta.25"
+	],
 	"92.0.4475.0": [
 		"14.0.0-nightly.20210426",
 		"14.0.0-nightly.20210427"
@@ -1456,6 +1470,12 @@ module.exports = {
 		"14.0.0-nightly.20210518",
 		"14.0.0-nightly.20210519"
 	],
+	"93.0.4577.58": [
+		"14.0.0"
+	],
+	"93.0.4577.63": [
+		"14.0.1"
+	],
 	"94.0.4584.0": [
 		"15.0.0-alpha.3",
 		"15.0.0-alpha.4",
@@ -1487,6 +1507,20 @@ module.exports = {
 		"16.0.0-nightly.20210820",
 		"16.0.0-nightly.20210823"
 	],
+	"94.0.4606.12": [
+		"15.0.0-alpha.10"
+	],
+	"94.0.4606.20": [
+		"15.0.0-beta.1",
+		"15.0.0-beta.2"
+	],
+	"94.0.4606.31": [
+		"15.0.0-beta.3",
+		"15.0.0-beta.4",
+		"15.0.0-beta.5",
+		"15.0.0-beta.6",
+		"15.0.0-beta.7"
+	],
 	"93.0.4530.0": [
 		"15.0.0-nightly.20210603",
 		"15.0.0-nightly.20210604"
@@ -1509,7 +1543,38 @@ module.exports = {
 		"15.0.0-nightly.20210702",
 		"15.0.0-nightly.20210705"
 	],
+	"94.0.4606.51": [
+		"15.0.0"
+	],
+	"95.0.4629.0": [
+		"16.0.0-alpha.1",
+		"16.0.0-nightly.20210902",
+		"16.0.0-nightly.20210903",
+		"16.0.0-nightly.20210906",
+		"16.0.0-nightly.20210907",
+		"16.0.0-nightly.20210908",
+		"16.0.0-nightly.20210909",
+		"16.0.0-nightly.20210910",
+		"16.0.0-nightly.20210913",
+		"16.0.0-nightly.20210914",
+		"16.0.0-nightly.20210915",
+		"16.0.0-nightly.20210916",
+		"16.0.0-nightly.20210917",
+		"16.0.0-nightly.20210920",
+		"16.0.0-nightly.20210921",
+		"16.0.0-nightly.20210922",
+		"17.0.0-nightly.20210923",
+		"17.0.0-nightly.20210924",
+		"17.0.0-nightly.20210927",
+		"17.0.0-nightly.20210928"
+	],
 	"95.0.4612.5": [
-		"16.0.0-nightly.20210824"
+		"16.0.0-nightly.20210824",
+		"16.0.0-nightly.20210825",
+		"16.0.0-nightly.20210826",
+		"16.0.0-nightly.20210827",
+		"16.0.0-nightly.20210830",
+		"16.0.0-nightly.20210831",
+		"16.0.0-nightly.20210901"
 	]
 };
\ No newline at end of file
