@@ -152,7 +152,8 @@ describe('NumberInput', function () {
             value: value,
             id: "test",
             label: "Number Input",
-            className: "extra-class"
+            className: "extra-class",
+            invalidText: "Number is not valid"
           }));
         };
 
@@ -183,10 +184,13 @@ describe('NumberInput', function () {
           var numberInput = getNumberInput(wrapper);
           expect(numberInput.prop('value')).toEqual(1);
         });
-        it('should set value to equal min when value < min', function () {
+        it('should set value when value < min and set invalid state', function () {
           var wrapper = getWrapper(5, 100, 0);
           var numberInput = wrapper.find('input');
-          expect(numberInput.prop('value')).toEqual(5);
+          var invalidText = wrapper.find(".".concat(prefix, "--form-requirement"));
+          expect(numberInput.prop('value')).toEqual(0);
+          expect(invalidText.length).toEqual(1);
+          expect(invalidText.text()).toEqual('Number is not valid');
         });
         it('should set value when min is undefined', function () {
           var wrapper = getWrapper(undefined, 100, 5);
@@ -244,7 +248,7 @@ describe('NumberInput', function () {
 
           expect(wrapper.find('NumberInput').instance().state.value).toEqual(2);
         });
-        it('should cap the number given to value prop', function () {
+        it('should not cap the number given to value prop', function () {
           // Enzyme doesn't seem to allow setState() in a forwardRef-wrapped class component
           wrapper.find('NumberInput').instance().setState({
             value: 0
@@ -256,14 +260,14 @@ describe('NumberInput', function () {
             max: 20
           }); // Enzyme doesn't seem to allow state() in a forwardRef-wrapped class component
 
-          expect(wrapper.find('NumberInput').instance().state.value).toEqual(10);
+          expect(wrapper.find('NumberInput').instance().state.value).toEqual(5);
           wrapper.setProps({
             value: 25,
             min: 10,
             max: 20
           }); // Enzyme doesn't seem to allow state() in a forwardRef-wrapped class component
 
-          expect(wrapper.find('NumberInput').instance().state.value).toEqual(20);
+          expect(wrapper.find('NumberInput').instance().state.value).toEqual(25);
         }); // NumberInput propTypes do not allow a string to be passed
 
         it.skip('should avoid capping when non-number prop is given to value prop', function () {
@@ -368,15 +372,15 @@ describe('NumberInput', function () {
       });
       it('should not invoke onClick when up arrow is clicked', function () {
         upArrow.simulate('click');
-        expect(onClick).not.toBeCalled();
+        expect(onClick).not.toHaveBeenCalled();
       });
       it('should not invoke onClick when down arrow is clicked', function () {
         downArrow.simulate('click');
-        expect(onClick).not.toBeCalled();
+        expect(onClick).not.toHaveBeenCalled();
       });
       it('should not invoke onChange when numberInput is changed', function () {
         input.simulate('change');
-        expect(onChange).not.toBeCalled();
+        expect(onChange).not.toHaveBeenCalled();
       });
     });
     describe('enabled numberInput', function () {
@@ -402,14 +406,14 @@ describe('NumberInput', function () {
       });
       it('should invoke onClick when numberInput is clicked', function () {
         input.simulate('click');
-        expect(onClick).toBeCalled();
+        expect(onClick).toHaveBeenCalled();
       });
       it('should invoke onClick when up arrow is clicked', function () {
         wrapper.setProps({
           value: 1
         });
         upArrow.simulate('click');
-        expect(onClick).toBeCalled();
+        expect(onClick).toHaveBeenCalled();
         expect(onClick).toHaveBeenCalledWith(expect.anything(), 'up', 2);
       });
       it('should only increase the value on up arrow click if value is less than max', function () {
@@ -419,7 +423,7 @@ describe('NumberInput', function () {
         upArrow.simulate('click'); // Enzyme doesn't seem to allow state() in a forwardRef-wrapped class component
 
         expect(wrapper.find('NumberInput').instance().state.value).toEqual(100);
-        expect(onClick).not.toBeCalled();
+        expect(onClick).not.toHaveBeenCalled();
       });
       it('should only decrease the value on down arrow click if value is greater than min', function () {
         wrapper.setProps({
@@ -428,7 +432,7 @@ describe('NumberInput', function () {
         downArrow.simulate('click'); // Enzyme doesn't seem to allow state() in a forwardRef-wrapped class component
 
         expect(wrapper.find('NumberInput').instance().state.value).toEqual(0);
-        expect(onClick).not.toBeCalled();
+        expect(onClick).not.toHaveBeenCalled();
       });
       it('should increase by the value of step', function () {
         wrapper.setProps({
@@ -454,20 +458,20 @@ describe('NumberInput', function () {
       });
       it('should not invoke onClick when down arrow is clicked and value is 0', function () {
         downArrow.simulate('click');
-        expect(onClick).not.toBeCalled();
+        expect(onClick).not.toHaveBeenCalled();
       });
       it('should invoke onClick when down arrow is clicked and value is above min', function () {
         wrapper.setProps({
           value: 1
         });
         downArrow.simulate('click');
-        expect(onClick).toBeCalled();
-        expect(onChange).toBeCalled();
+        expect(onClick).toHaveBeenCalled();
+        expect(onChange).toHaveBeenCalled();
         expect(onClick).toHaveBeenCalledWith(expect.anything(), 'down', 0);
       });
       it('should invoke onChange when numberInput is changed', function () {
         input.simulate('change');
-        expect(onChange).toBeCalled();
+        expect(onChange).toHaveBeenCalled();
         expect(onChange).toHaveBeenCalledWith(expect.anything(), expect.anything());
       });
     });
