@@ -2,8 +2,6 @@
 
 var _react = _interopRequireDefault(require("react"));
 
-var _carbonComponents = require("carbon-components");
-
 var _enzyme = require("enzyme");
 
 var _Tabs = _interopRequireDefault(require("../Tabs"));
@@ -16,12 +14,12 @@ function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { de
 
 function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }
 
-var prefix = _carbonComponents.settings.prefix;
+var prefix = 'bx';
 Element.prototype.scrollIntoView = jest.fn();
 describe('Tabs', function () {
   describe('renders as expected', function () {
     describe('navigation (<div>)', function () {
-      var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_Tabs.default, {
+      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_Tabs.default, {
         className: "extra-class"
       }, /*#__PURE__*/_react.default.createElement(_Tab.default, {
         label: "firstTab"
@@ -40,7 +38,7 @@ describe('Tabs', function () {
         expect(wrapper.find('div').first().hasClass("".concat(prefix, "--tabs--scrollable"))).toBe(true);
       });
       it('supports container variant', function () {
-        expect((0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_Tabs.default, {
+        expect((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_Tabs.default, {
           className: "extra-class",
           type: "container"
         }, /*#__PURE__*/_react.default.createElement(_Tab.default, {
